{% comment %}

    IMPORTANT NOTE: Some editors automatically add a NEW LINE at the end of the document. This causes undesired extra space after the <a> tag. So every time you adjust this file, make sure to open/save it in an editor that does NOT add a new line before committing.

{% endcomment %}

<a href="{{ link_url }}" class="{{ link_classes }}" {{ link_attributes }} {% if link_id %}id="{{ link_id }}"{% endif %}>{% include "partials/buttons/link_text.html" %}</a>
{% if 'softpage' in link_attributes %}{% if modal_header_title %}{% include "modals/modal-header-markup.html" with title=modal_header_title %}{% else %}{% include "modals/modal-header-markup.html" with title=link_label %}{% endif %}{% endif %}
