{% load i18n %}

<div class="newsletter-plugin">
    <div class="success">
        <div class="success__icon"></div>
        <h1 class="heading">{% trans "Thanks for your registration." %}</h1>
    </div>
</div>
