# Generated by Django 2.1.8 on 2019-07-03 09:57

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContactRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('salutation', models.IntegerField(choices=[(1, 'Mr.'), (2, 'Mrs.')], null=True, verbose_name='Salutation')),
                ('first_name', models.CharField(max_length=255, null=True, verbose_name='First Name')),
                ('last_name', models.CharField(max_length=255, null=True, verbose_name='Last Name')),
                ('email', models.EmailField(max_length=254, null=True, verbose_name='Email')),
                ('company_name', models.CharField(blank=True, max_length=255, null=True, verbose_name='Company')),
                ('phone', models.CharField(blank=True, max_length=30, null=True, verbose_name='Phone')),
                ('message', models.TextField(blank=True, max_length=255, null=True, verbose_name='Message')),
                ('contact_type', models.IntegerField(choices=[(None, '-- please choose --'), (10, 'Phone'), (20, 'Email')], verbose_name='Please contact me via')),
                ('date', models.DateField(blank=True, null=True, verbose_name='Date')),
                ('time', models.IntegerField(blank=True, choices=[(None, '-- between --'), (1, '09:00-11:00'), (2, '13:00-15:00'), (3, '15:00-17:00')], null=True, verbose_name='Time')),
            ],
            options={
                'verbose_name': 'Contact Request',
                'verbose_name_plural': 'Contact Requests',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ContactRequestPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='contact_contactrequestplugin', serialize=False, to='cms.CMSPlugin')),
                ('send_internal_mail', models.BooleanField(default=True, help_text='Send confirmation mail to defined internal e-mail addresses.', verbose_name='Send internal e-mail')),
                ('internal_email_addresses', django.contrib.postgres.fields.ArrayField(base_field=models.EmailField(blank=True, max_length=254, null=True), blank=True, null=True, size=None, verbose_name='Internal e-mail addresses')),
                ('from_email_address', models.EmailField(blank=True, max_length=254, null=True, verbose_name='Sender e-mail address')),
                ('send_external_mail', models.BooleanField(default=True, help_text='Send confirmation mail to customer.', verbose_name='Send external e-mail')),
                ('thank_you_text', models.TextField(blank=True, help_text='This text will be shown, after form completion.', null=True, verbose_name='Thank you text')),
                ('label_layout', models.CharField(choices=[('stacked', 'Stacked with fields'), ('side_by_side', 'Side by side with fields'), ('placeholder', 'As placeholders')], default='stacked', max_length=15, verbose_name='Display labels')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
