# Generated by Django 2.1.8 on 2019-07-02 17:18

import cms.models.fields
from django.db import migrations, models
import django.db.models.deletion
import djangocms_text_ckeditor.fields
import parler.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkTerms',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.DateTimeField(blank=True, null=True, verbose_name='start')),
                ('end', models.DateTimeField(blank=True, null=True, verbose_name='end')),
                ('status', models.IntegerField(choices=[(10, 'Draft'), (20, 'Published'), (30, 'Archived')], default=10, verbose_name='Status')),
                ('terms_cms_page', cms.models.fields.PageField(help_text='CMS Page which shows Terms and Conditions', null=True, on_delete=django.db.models.deletion.PROTECT, to='cms.Page', verbose_name='Terms cms Page')),
            ],
            options={
                'verbose_name': 'Terms of Service',
                'verbose_name_plural': 'Terms of Service',
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='AllinkTermsPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_terms_allinktermsplugin', serialize=False, to='cms.CMSPlugin')),
            ],
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AllinkTermsTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(db_index=True, max_length=15, verbose_name='Language')),
                ('text', djangocms_text_ckeditor.fields.HTMLField(verbose_name='Terms Text')),
                ('master', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='allink_terms.AllinkTerms')),
            ],
            options={
                'verbose_name': 'Terms of Service Translation',
                'db_table': 'allink_terms_allinkterms_translation',
                'db_tablespace': '',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.AlterUniqueTogether(
            name='allinktermstranslation',
            unique_together={('language_code', 'master')},
        ),
    ]
